/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#ifndef __FormFillController_h__
#define __FormFillController_h__

#import <Cocoa/Cocoa.h>
#import "FormFillPopup.h"

#include "nsIDOMHTMLInputElement.h"

@class CHBrowserView;

class KeychainAutoCompleteSession;
class nsIAutoCompleteResults;
class FormFillListener;

@interface FormFillController : NSObject
{
  NSMutableArray*          mBrowserViews;
  NSMutableArray*          mPopups;

  NSMutableString*         mSearchString;
 
  KeychainAutoCompleteSession*  mKeychainSession;
  nsIAutoCompleteResults*  mResults;
  FormFillListener*        mListener;

  FormFillPopup*           mFocusedPopup;
  CHBrowserView*           mFocusedView;
  nsIDOMHTMLInputElement*  mFocusedInput;

  // determines if the search currently pending should complete the default 
  // result when it is ready. Used to prevent backspace/delete from autocompleting
  BOOL mCompleteResult;

  // mUsernameFillEnabled determines whether we send searches to the Keychain Service
  // Form fill history value can be added here as well
  BOOL mUsernameFillEnabled;
}

+ (FormFillController*) instance;

- (void) attachToBrowser:(CHBrowserView*)browser withPopup:(FormFillPopup*)popup;
- (void) detachFromBrowser:(CHBrowserView*)aBrowser;

// Callback function for when item in focused popup window is clicked
- (void) popupSelected;

@end

#endif
